//*****************************************************************************
//
// TLC59116.h - Header file for the TI TLC59116 LED driver
//
// THIS SOFTWARE IS PROVIDED "AS IS" AND WITH ALL FAULTS.
// NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT
// NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT, UNDER
// ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
// DAMAGES, FOR ANY REASON WHATSOEVER.
//
// AUTHOR: JOERG QUINTEN
// E2E-NICKNAME: aBUGSworstnightmare
//
//*****************************************************************************

#ifndef TLC59116_H_
#define TLC59116_H_

//*****************************************************************************
//
// Device parameters. Here you will need to define the I2C address for the
// specific part.  It needs to be in following format:
//
//                      [A6]:[A5]:[A4]:[A3]:[A2]:[A1]:[A0]:[R/W]
//
// The TCA6507 has a fixed I2C address
//                      [1]:[0]:[0]:[0]:[1]:[0]:[1]:[R/W]
//
//*****************************************************************************
#define TCA6507						0x8A

//*****************************************************************************
//
// Register command definitions.  These are the values that can be used for the
// ucReg parameter.  Reference the TLC59116 data sheet for more information on
// registers and values.
//
//*****************************************************************************
#define REG_MODE1				0x00
#define REG_MODE2				0x01
#define REG_PWM0				0x02
#define REG_PWM1				0x03
#define REG_PWM2				0x04
#define REG_PWM3				0x05
#define REG_PWM4				0x06
#define REG_PWM5				0x07
#define REG_PWM6				0x08
#define REG_PWM7				0x09
#define REG_PWM8				0x0A
#define REG_PWM9				0x0B
#define REG_PWM10				0x0C
#define REG_PWM11				0x0D
#define REG_PWM12				0x0E
#define REG_PWM13				0x0F
#define REG_PWM14				0x10
#define REG_PWM15				0x11
#define REG_GRPPWM				0x12
#define REG_GRPFREQ				0x13
#define REG_LEDOUT0				0x14
#define REG_LEDOUT1				0x15
#define REG_LEDOUT2				0x16
#define REG_LEDOUT3				0x17
#define REG_SUBADR1				0x18
#define REG_SUBADR2				0x19
#define REG_SUBADR3				0x1A
#define REG_ALLCALLADR			0x1B
#define REG_IREF				0x1C
#define REG_EFLAG1				0x1D
#define REG_EFLAG2				0x1E

//*****************************************************************************
//
// Auto-Increment Options.
// Use together with the ucReg parameter, i.e. ucReg = (REG_PWM0|AUTO_BRIGHTNESS)
// 	--> Auto-Increment individual brightness registers only, start with REG_PWM0
//
//*****************************************************************************
#define AUTO_ALL				0x80
#define AUTO_BRIGHTNESS			0xA0
#define AUTO_GLOBAL				0xC0
#define AUTO_GLOBRIGHT			0xE0

//*****************************************************************************
//
// REG_MODE1 Options.
// Write these data into REG_MODE1
// SUB1ALL: Device acknowledges SUBADR1 & ALLCALLADR address
//
//*****************************************************************************
#define MODE1_SUB1ALL			0x09

//*****************************************************************************
//
// Device parameters. Here you will need to define the I2C address for the
// specific part.  It needs to be in following format:
//
//                      [A6]:[A5]:[A4]:[A3]:[A2]:[A1]:[A0]:[R/W]
//
// The TLC59116 has a programmable I2C address
//                      [1]:[1]:[0]:[A3]:[A2]:[A1]:[A0]:[R/W]
//
// The default power-up values are:
// ALLCALLADR			[1]:[1]:[0]:[1]:[0]:[0]:[0]:[R/W] = 0x68 = 0xD0
// SUBADR1				[1]:[1]:[0]:[1]:[0]:[0]:[1]:[R/W] = 0x69
// SUBADR2				[1]:[1]:[0]:[1]:[0]:[1]:[0]:[R/W] = 0x6A
// SUBADR3				[1]:[1]:[0]:[1]:[1]:[0]:[0]:[R/W] = 0x6C
// SWRSTCALL			[1]:[1]:[0]:[1]:[0]:[1]:[1]:[R/W] = 0x6B
//
// Note: At power-up, Sub Call I2C bus address is disabled!
//
//*****************************************************************************
#define TLC59116					0x68

//
// a set of Sub Call I2C addresses
// they were written to the Sub Call address registers to ease group addressing
//
#define SUBGROUP1					0x69	// 0xD2
#define SUBGROUP2					0x6A	// 0xD4
#define SUBGROUP3					0x6C	// 0xD8
#define SUBGROUP4					0x6E	// 0xDC

//*****************************************************************************
//
// arrays for TLC59116 initialization
//
//*****************************************************************************
// clears all PWMx registers to ZERO (0)
static const char TLC59116_cleararray [] = {
										0x00, 0x00, 0x00, 0x00,
										0x00, 0x00, 0x00, 0x00,
										0x00, 0x00, 0x00, 0x00,
										0x00, 0x00, 0x00, 0x00};

// some colours
static const char TLC59116_code1 [] = {
										0x10, 0x00, 0x00, 0x00,
										0x00, 0x20, 0x07, 0x00,
										0x00, 0x0A, 0x0B, 0x00,
										0xaa, 0x00, 0x10, 0x00};

// red only
static const char TLC59116_red [] = {
										0xFF, 0x00, 0x00, 0x00,
										0xFF, 0x00, 0x00, 0x00,
										0xFF, 0x00, 0x00, 0x00,
										0xFF, 0x00, 0x00, 0x00};

// blue only
static const char TLC59116_blue [] = {
										0x00, 0x00, 0xFF, 0x00,
										0x00, 0x00, 0xFF, 0x00,
										0x00, 0x00, 0xFF, 0x00,
										0x00, 0x00, 0xFF, 0x00};

// initializes all TLC59116-slaves for operation
static const char TLC59116_initarray [] = {
										0x01, 0x00,					// REG_MODE1, REG_MODE2
										0xFF, 0x00, 0x00, 0x00,		// PWM0 = RED, PWM2 to PWM 3 OFF
										0x00, 0xFF, 0x00, 0x00,		// PWM4 = GREEN, PWM5 to PWM7 OFF
										0x00, 0x00, 0xFF, 0x00,		// PWM8 = BLUE, PWM9 to PWM11 OFF
										0xFF, 0xFF, 0xFF, 0x00,		// PWM12 to PWM14 = ON --> WHITE, PWM15 OFF
										0xFF, 0xFF,					// REG_GRPPWM, REG_GRPFREQ
										0xAA, 0xAA, 0xAA, 0xAA};	// REG_LEDOUT0 to REG_LEDOUT3



#endif /* TLC59116_H_ */
